package java.util.zip;

import java.io.IOException;
import java.io.InputStream;
import java.io.FilterInputStream;

public class CheckedInputStream extends FilterInputStream
{
    private Checksum cksum;
    
    public CheckedInputStream(InputStream in, Checksum cksum) {
        super(in);
        this.cksum = cksum;
    }
    
    @Override
    public int read() throws IOException {
        int read = this.in.read();
        if (read != -1) {
            this.cksum.update(read);
        }
        return read;
    }
    
    @Override
    public int read(byte[] b, int off, int read) throws IOException {
        read = this.in.read(b, off, read);
        if (read != -1) {
            this.cksum.update(b, off, read);
        }
        return read;
    }
    
    @Override
    public long skip(long n) throws IOException {
        byte[] array = new byte[512];
        long n2 = 0L;
        while (n2 < n) {
            long n3 = n - n2;
            long n4 = (long)this.read(array, 0, (n3 < (long)array.length) ? ((int)n3) : array.length);
            if (n4 == -1L) {
                return n2;
            }
            n2 += n4;
        }
        return n2;
    }
    
    public Checksum getChecksum() {
        return this.cksum;
    }
}
